<?php

function getMovieCastAndDetails($tmdbId, $apiKey) {
    // TMDB API URLs
    $creditsUrl = "https://api.themoviedb.org/3/movie/$tmdbId/credits?api_key=$apiKey";
    $basePersonUrl = "https://api.themoviedb.org/3/person/";
    $imageBaseUrl = "https://image.tmdb.org/t/p/w500";

    // Fetch cast list
    $creditsResponse = file_get_contents($creditsUrl);
    $creditsData = json_decode($creditsResponse, true);

    // Initialize arrays to hold cast and crew details
    $castWithDetails = [];
    $crewMembers = []; // Initialize an associative array to prevent duplicates

    // Check if cast exists
    if (isset($creditsData['cast'])) {
        foreach ($creditsData['cast'] as $castMember) {
            // Fetch individual cast member details (including biography)
            $personId = $castMember['id'];
            $personDetailsResponse = file_get_contents($basePersonUrl . $personId . "?api_key=$apiKey");
            $personDetails = json_decode($personDetailsResponse, true);

            // Add cast member with biography and other details
            $castWithDetails[] = [
                "name" => $castMember['name'],
                "character" => $castMember['character'],
                "profile_path" => $imageBaseUrl . $castMember['profile_path'],
                "biography" => $personDetails['biography'] ?? "Biography not available",
                "birthday" => $personDetails['birthday'] ?? "Unknown",
                "place_of_birth" => $personDetails['place_of_birth'] ?? "Unknown",
            ];
        }
    }

    // Collect crew members for directors, writers, producers, and musicians
    if (isset($creditsData['crew']) && is_array($creditsData['crew'])) {
        foreach ($creditsData['crew'] as $crewMember) {
            // Check for specific roles of interest
            if (in_array($crewMember['job'], ['Director', 'Producer', 'Writer', 'Music Supervisor', 'Composer', 'Musician'])) {
                // Check if the crew member already exists
                if (!isset($crewMembers[$crewMember['name']])) {
                    $crewMembers[$crewMember['name']] = [
                        "name" => $crewMember['name'],
                        "jobs" => [], // Initialize jobs array
                        "profile_path" => isset($crewMember['profile_path']) ? $imageBaseUrl . $crewMember['profile_path'] : null,
                    ];
                }
                // Add job to the existing crew member
                $crewMembers[$crewMember['name']]['jobs'][] = $crewMember['job'];
            }
        }

        // Optional: Sort jobs and remove duplicates
        foreach ($crewMembers as &$member) {
            $member['jobs'] = array_unique($member['jobs']); // Remove duplicate job entries
            sort($member['jobs']); // Optional: Sort the jobs for better readability
        }
    }

    // Combine cast and crew details into final output
    $output = [
        "cast" => $castWithDetails,
        "crew" => array_values($crewMembers), // Convert associative array to indexed array
    ];

    // Return JSON response with separated cast and crew
    header('Content-Type: application/json');
    echo json_encode($output, JSON_PRETTY_PRINT);
}

// Example usage with parameters from the URL
$tmdbId = $_GET['tmdb_id'] ?? null;  // Movie ID from URL parameter
$apiKey = $_GET['api_key'] ?? null;   // API Key from URL parameter

if ($tmdbId && $apiKey) {
    getMovieCastAndDetails($tmdbId, $apiKey);
} else {
    echo json_encode(["error" => "Invalid TMDB ID or API Key"], JSON_PRETTY_PRINT);
}
